'use strict';

function _interopDefault(ex) {
  return ex && typeof ex === 'object' && 'default' in ex ? ex['default'] : ex;
}

var core = require('@emotion/core');

var EditorJs = _interopDefault(require('react-editor-js'));

var fields = require('@arch-ui/fields');

var theme = require('@arch-ui/theme');

var Embed = _interopDefault(require('@editorjs/embed'));

var Table = _interopDefault(require('@editorjs/table'));

var List = _interopDefault(require('@editorjs/list'));

var Warning = _interopDefault(require('@editorjs/warning'));

var Code = _interopDefault(require('@editorjs/code'));

var LinkTool = _interopDefault(require('@editorjs/link'));

var Image = _interopDefault(require('@editorjs/image'));

var Raw = _interopDefault(require('@editorjs/raw'));

var Header = _interopDefault(require('@editorjs/header'));

var Quote = _interopDefault(require('@editorjs/quote'));

var Marker = _interopDefault(require('@editorjs/marker'));

var CheckList = _interopDefault(require('@editorjs/checklist'));

var Delimiter = _interopDefault(require('@editorjs/delimiter'));

var InlineCode = _interopDefault(require('@editorjs/inline-code'));

var SimpleImage = _interopDefault(require('@editorjs/simple-image')); // tools.js


const EDITOR_JS_TOOLS = {
  embed: Embed,
  table: Table,
  // paragraphTool: Paragraph,
  list: List,
  warning: Warning,
  code: Code,
  linkTool: LinkTool,
  image: Image,
  raw: Raw,
  header: Header,
  quote: Quote,
  marker: Marker,
  checklist: CheckList,
  delimiter: Delimiter,
  inlineCode: InlineCode,
  simpleImage: SimpleImage
};
/** @jsx jsx */

const EditorJsField = ({
  onChange,
  field,
  errors,
  value: serverValue
}) => {
  const handleChange = value => {
    onChange(value);
  }; // const value = serverValue || {blocks:[]};


  const value = serverValue || {
    blocks: []
  };
  const htmlID = `ks-input-${field.path}`;
  const accessError = errors.find(error => error instanceof Error && error.name === 'AccessDeniedError');
  if (accessError) return null;
  return core.jsx(fields.FieldContainer, null, core.jsx(fields.FieldLabel, {
    htmlFor: htmlID,
    field: field,
    errors: errors
  }), core.jsx("div", {
    css: {
      border: `1px ${theme.colors.N20} solid`,
      borderRadius: theme.borderRadius,
      padding: `${theme.gridSize}px`
    }
  }, core.jsx(EditorJs, {
    data: value,
    tools: EDITOR_JS_TOOLS,
    onChange: async e => {
      handleChange(await e.saver.save());
    },
    css: {
      display: 'flex',
      padding: `${theme.gridSize}px 0`,
      borderBottom: `1px solid ${theme.colors.N10}`,
      marginBottom: `${theme.gridSize}px`
    }
  })));
};

exports.default = EditorJsField;
