import { jsx } from '@emotion/core';
import EditorJs from 'react-editor-js';
import { FieldContainer, FieldLabel } from '@arch-ui/fields';
import { colors, borderRadius, gridSize } from '@arch-ui/theme';
import Embed from '@editorjs/embed';
import Table from '@editorjs/table';
import List from '@editorjs/list';
import Warning from '@editorjs/warning';
import Code from '@editorjs/code';
import LinkTool from '@editorjs/link';
import Image from '@editorjs/image';
import Raw from '@editorjs/raw';
import Header from '@editorjs/header';
import Quote from '@editorjs/quote';
import Marker from '@editorjs/marker';
import CheckList from '@editorjs/checklist';
import Delimiter from '@editorjs/delimiter';
import InlineCode from '@editorjs/inline-code';
import SimpleImage from '@editorjs/simple-image'; // tools.js

const EDITOR_JS_TOOLS = {
  embed: Embed,
  table: Table,
  // paragraphTool: Paragraph,
  list: List,
  warning: Warning,
  code: Code,
  linkTool: LinkTool,
  image: Image,
  raw: Raw,
  header: Header,
  quote: Quote,
  marker: Marker,
  checklist: CheckList,
  delimiter: Delimiter,
  inlineCode: InlineCode,
  simpleImage: SimpleImage
};
/** @jsx jsx */

const EditorJsField = ({
  onChange,
  field,
  errors,
  value: serverValue
}) => {
  const handleChange = value => {
    onChange(value);
  }; // const value = serverValue || {blocks:[]};


  const value = serverValue || {
    blocks: []
  };
  const htmlID = `ks-input-${field.path}`;
  const accessError = errors.find(error => error instanceof Error && error.name === 'AccessDeniedError');
  if (accessError) return null;
  return jsx(FieldContainer, null, jsx(FieldLabel, {
    htmlFor: htmlID,
    field: field,
    errors: errors
  }), jsx("div", {
    css: {
      border: `1px ${colors.N20} solid`,
      borderRadius,
      padding: `${gridSize}px`
    }
  }, jsx(EditorJs, {
    data: value,
    tools: EDITOR_JS_TOOLS,
    onChange: async e => {
      handleChange(await e.saver.save());
    },
    css: {
      display: 'flex',
      padding: `${gridSize}px 0`,
      borderBottom: `1px solid ${colors.N10}`,
      marginBottom: `${gridSize}px`
    }
  })));
};

export default EditorJsField;
